From 0f15df24eca6d81eee7544501b3b8633c57644cc Mon Sep 17 00:00:00 2001
From: Albrecht Schlosser <albrechts.fltk@online.de>
Date: Sun, 5 Dec 2021 20:05:07 +0100
Subject: [PATCH] Fix "Tiny window problem ..." (STR 3352)

... if child group larger than window
(https://www.fltk.org/str.php?L3352)

Applied fix_str_3352_v2_fltk-1.4.x.patch and rebased.
---
 src/Fl_cocoa.mm  |  8 +++++---
 src/Fl_win32.cxx | 14 ++++++--------
 src/Fl_x.cxx     |  8 +++++---
 3 files changed, 16 insertions(+), 14 deletions(-)

diff --git a/src/Fl_cocoa.mm b/src/Fl_cocoa.mm
index e15115026..5cf74ea3e 100644
--- a/src/Fl_cocoa.mm
+++ b/src/Fl_cocoa.mm
@@ -2954,9 +2954,11 @@ Fl_X* Fl_Cocoa_Window_Driver::makeWindow()
   } else {
     if (w->resizable()) {
       Fl_Widget *o = w->resizable();
-      int minw = o->w(); if (minw > 100) minw = 100;
-      int minh = o->h(); if (minh > 100) minh = 100;
-      w->size_range(w->w() - o->w() + minw, w->h() - o->h() + minh, 0, 0);
+      int minw = w->w();                     // minw is window's initial width
+      int minh = w->h();                     // minh is window's initial height
+      int maxw = (o->w() == 0) ? minw : 0;   // if resizable w()==0, disable resize w()
+      int maxh = (o->h() == 0) ? minh : 0;   // if resizable h()==0, disable resize h()
+      w->size_range(minw, minh, maxw, maxh);
       if (w->border()) winstyle |= NSResizableWindowMask;
     } else {
       w->size_range(w->w(), w->h(), w->w(), w->h());
diff --git a/src/Fl_win32.cxx b/src/Fl_win32.cxx
index 9abbb5d58..0418dcc56 100644
--- a/src/Fl_win32.cxx
+++ b/src/Fl_win32.cxx
@@ -2069,14 +2069,12 @@ Fl_X *Fl_WinAPI_Window_Driver::makeWindow() {
   } else {
     if (!size_range_set()) {
       if (w->resizable()) {
-        Fl_Widget *o = w->resizable();
-        int minw = o->w();
-        if (minw > 100)
-          minw = 100;
-        int minh = o->h();
-        if (minh > 100)
-          minh = 100;
-        w->size_range(w->w() - o->w() + minw, w->h() - o->h() + minh, 0, 0);
+	Fl_Widget *o = w->resizable();
+	int minw = w->w();                     // minw is window's initial width
+	int minh = w->h();                     // minh is window's initial height
+	int maxw = (o->w() == 0) ? minw : 0;   // if resizable w()==0, disable resize w()
+	int maxh = (o->h() == 0) ? minh : 0;   // if resizable h()==0, disable resize h()
+	w->size_range(minw, minh, maxw, maxh);
       } else {
         w->size_range(w->w(), w->h(), w->w(), w->h());
       }
diff --git a/src/Fl_x.cxx b/src/Fl_x.cxx
index a57316207..55c249ecd 100644
--- a/src/Fl_x.cxx
+++ b/src/Fl_x.cxx
@@ -2791,9 +2791,11 @@ void Fl_X11_Window_Driver::sendxjunk() {
   if (!size_range_set()) { // default size_range based on resizable():
     if (w->resizable()) {
       Fl_Widget *o = w->resizable();
-      int minw = o->w(); if (minw > 100) minw = 100;
-      int minh = o->h(); if (minh > 100) minh = 100;
-      w->size_range(w->w() - o->w() + minw, w->h() - o->h() + minh, 0, 0);
+      int minw = w->w();                     // minw is window's initial width
+      int minh = w->h();                     // minh is window's initial height
+      int maxw = (o->w() == 0) ? minw : 0;   // if resizable w()==0, disable resize w()
+      int maxh = (o->h() == 0) ? minh : 0;   // if resizable h()==0, disable resize h()
+      w->size_range(minw, minh, maxw, maxh);
     } else {
       w->size_range(w->w(), w->h(), w->w(), w->h());
     }
-- 
2.25.1

